@@ -2,7 +2,6 @@
 Abstraction layer to construct a workflow node using and airflow operator
 """
 from collections.abc import Iterable
-from os import environ
 from typing import List
 from typing import Tuple
 from typing import Type
@@ -20,13 +19,11 @@ class Node:
     Abstraction to create a node in the implemented engine api (airflow)
     """
 
-    # location code for the node is expected to be installable from
-    code_mount: str = environ.get("CODE_MOUNT", "/opt/airflow/code/")
-
     def __init__(
         self,
         workflow_name: str,
         workflow_version: str,
+        workflow_package: str,
         task: task_type_hint,
         upstreams: upstreams_type_hint = None,
     ):
@@ -45,6 +42,7 @@ class Node:
         self.workflow_name = workflow_name
         self.workflow_version = workflow_version
         self.task = task
+        self.workflow_package = workflow_package
         self.upstreams = upstreams
 
     @property
@@ -111,9 +109,11 @@ exit $exit_code"""
 
     @property
     def _install_command(self):
-        return (
-            f"pip install {self.code_mount}{self.task.__module__.split('.')[0].replace('_', '-')}"
-        )
+        repo_name = self.workflow_package.split(".")[0].replace("_", "-")
+        version = self.workflow_version
+        artifact_folder = f"{repo_name}_{version}/"
+        # location $CODE_MOUNT is the base path on the worker the code should be installable from
+        return f'pip install $CODE_MOUNT"{artifact_folder}{repo_name}"'
 
     @property
     def _run_command(self):
@@ -122,6 +122,6 @@ exit $exit_code"""
     @property
     def _python(self):
         return f"""from {self.task.__module__} import {self.task.__name__}
-task = {self.task.__name__}(recipe_run_id={{{{dag_run.conf['recipe_run_id']}}}}, workflow_name='{self.workflow_name}', workflow_version='{self.workflow_version}')
-task()
+with {self.task.__name__}(recipe_run_id={{{{dag_run.conf['recipe_run_id']}}}}, workflow_name='{self.workflow_name}', workflow_version='{self.workflow_version}') as task:
+    task()
 """
